Skip to contents

Produces simple ggplot2 summaries for available validation metrics.

Usage

# S3 method for class 'gmov_generative'
plot(x, metric = NULL, ...)

Arguments

x

An object returned by validate_ssf_generative().

metric

Optional metric to plot. If NULL, all available plots are printed and returned as a named list.

...

Currently unused.

Value

A ggplot object when metric is supplied, otherwise an invisible named list of ggplot objects.